package org.example.dfsort;

import java.io.BufferedOutputStream;
import java.io.IOException;
import java.util.Iterator;
import java.util.List;

import org.apache.log4j.Logger;

import com.ibm.jzos.DfSort;
import com.ibm.jzos.RDWOutputRecordStream;

public class CreateDFSort
{
	private static final Logger LOG = Logger.getLogger(CreateDFSort.class);
	
	private DfSort dfSort;
	private String outputFile;
	private int lRecLen = 128;
	private RDWOutputRecordStream sortInputData;
	
	public CreateDFSort(String dsn)
	{
		LOG.debug("Creating DFSort");
		dfSort = new DfSort();
		outputFile = dsn;
	}
	
	public void startSort()
	{
		LOG.debug("Startign Sort");
		
		//Direct DFSORT to read input from Java.
		dfSort.setInputStreamHasRdws();
		
		//Direct DFSORT to send its output (SORTOUT) to the supplied DSN.
		dfSort.addAllocation("alloc fi(sortout) da(" 
				+ outputFile + ") reuse shr msg(2)");
		
		// the input record is a fixed format String
		// starting at offset 79, is 3 char in length
		//  (this offset includes the 4 byte RDW for the variable 
		//  length record)
		// and in the format of "Unsigned Free Form Numeric"
		// sort in Ascending order
		dfSort.addControlStatement("SORT FIELDS=(79,3,UFF,A)");
		
		// for this example I am using a Variable Length record
		// w/ a Record Length of 128
		dfSort.addControlStatement("RECORD TYPE=V,LENGTH=(" + lRecLen + ")");
		
		//Kick off the sort.  
		LOG.debug("Running Sort");
		dfSort.execute();
		
		// Set the sort input as a Java Record Stream
		// so I can release records one at a time to the sort
		LOG.debug("Building Sort input");
		sortInputData = new RDWOutputRecordStream(
				new BufferedOutputStream(dfSort.getChildStdinStream()));
	}
	
	public void addRecord(String record) throws IOException
	{
		// release a Java record (string) to the sort
		LOG.trace("Adding record: " + record);
		byte[] data = record.getBytes();
		sortInputData.write(data, 0, data.length); 
	}
	
	@SuppressWarnings("unchecked")
	public int processSort() throws IOException
	{
		LOG.debug("Finishing Sort");
		sortInputData.close();
		
		//Wait for dfSort to finish and check the result
		int rc = dfSort.getReturnCode();
		LOG.debug("Sort return code: " + rc);
		if (rc != 0 ) 
		{
			List<String> stderrLines = dfSort.getStderrLines();
			for (Iterator<String> i = stderrLines.iterator(); i.hasNext(); ) 
			{
				LOG.error(i.next());
			}
		}
		return rc;
	}
	
}
