package org.example.dfsort;

import org.apache.log4j.Logger;

import com.ibm.jzos.ZFile;

public class CreateZFile
{
	private static final Logger LOG = Logger.getLogger(CreateZFile.class);
	private String dsn = null;
	
	public void create(String fileName)
	{
		LOG.debug("Stating ZFile create for file: " + fileName);
		try
		{
			// bpxwdyn requires fully-qualified DSN
			// so we make sure that we have a fully qualified DSN
			dsn = ZFile.getFullyQualifiedDSN(fileName);
			LOG.trace("Qualified DSN is: " + dsn);

			// allocate new DDNAME to "DUMMY" that we will reuse to allocate the
			// new file
			String targetDD = ZFile.allocDummyDDName();
			// file creation
			ZFile.bpxwdyn("alloc fi(" + targetDD + ") "  
			        + "da(" + dsn + ") "
			        + "reuse new dsorg(ps) "
			        + "lrecl(128) recfm(v,b) "  
					+ "tracks space(1,1) blksize(6144) "
			        + "catalog msg(wtp)");

			// free the ddname associated with the dataset
			ZFile.bpxwdyn("free fi(" + targetDD + ") msg(wtp)");

			if (ZFile.exists("//'" + dsn + "'"))
			{
				LOG.debug("File " + fileName
						+ " was successfully created");
			}
			else
			{
				LOG.debug("File " + fileName + " cannot be created");
			}
		}
		catch (Exception e)
		{
			LOG.error("Something went wrong: " + e.getMessage());
		}
	}
	
	public String getDSN()
	{
		LOG.debug("Returning DSN : " + dsn);
		return dsn;
	}
}

