package org.example.dfsort;

import org.apache.log4j.Logger;

/*
 * This example will:
 *   1) Read an input file into memory
 *   2) Allocate an MVS Variable Blocked file to hold the sort results
 *   3) Define the DFSort routine
 *   4) Loop thru each input record and build a fixed format string
 *         The format is:
 *           name: 35 char string
 *           a colon
 *           a space
 *           users: 12 digit integer
 *           a space
 *           population: 12 digit integer
 *           a space
 *           rank: 3 digit integer
 *           a space
 *           percentage: 5 digit floating point w/ a decimal point
 *           a percent sign
 *           a space
 *           percentageRank: 3 digit integer 
 *      total record size: 77 bytes
 *   5) Release the record to DFSort
 *   6) Process the sort, and get the return code  
 */
public class DFSortPlay {
	
	private static final Logger LOG = Logger.getLogger(DFSortPlay.class);

	public static void main(String[] args)
	{
		LOG.debug("Starting DFSort Appl");
		String fileName = "InternetUsers.csv";
		InputHandler inputHandler = new InputHandler();
		LOG.debug("Reading input file: " + fileName);
		inputHandler.readFile(fileName);
		
		CreateZFile createZFile = new CreateZFile();
		String results = "dfsort.results";
		LOG.debug("Creating output file: " + results);
		
		// this will create '<TSOID>.dfsort.results' 
		createZFile.create(results);
		String qualifiedDSN = createZFile.getDSN();
		
		CreateDFSort createDFSort = new CreateDFSort(qualifiedDSN);
		createDFSort.startSort();

		try
		{
			// note I start at 1 to skip the header line
			for (int i = 1; i < inputHandler.getSize(); i++)
			{
				String record = inputHandler.getRecord(i);
				LOG.trace(record);
				SortRecord sortRecord = new SortRecord(record);
				createDFSort.addRecord(sortRecord.buildOutputRecord());
			}
			int returnCode = createDFSort.processSort();
			LOG.debug("Sort return code: " + returnCode);
		}
		catch (Exception e)
		{
			LOG.error(e.getMessage());
			System.exit(4);
		}
		
		System.exit(0);
	}
}